@@ -1,7 +1,7 @@
 #
 # This file is part of Config-Model-Itself
 #
-# This software is Copyright (c) 2007-2017 by Dominique Dumont.
+# This software is Copyright (c) 2007-2019 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -25,7 +25,10 @@
 #    along with Config-Model-Itself; if not, write to the Free Software
 #    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 
-[
+use strict;
+use warnings;
+
+return [
     [
         name => "Itself::Class",
         author => 'Dominique Dumont',
@@ -62,7 +65,7 @@
                         code => 'not defined $_ or eval{Mouse::Util::load_class($_)}; not $@;',
                         msg  => 'Error while loading $_ class ',
                     },
-                    "2_class_inherit" => {
+                   "2_class_inherit" => {
                         code => 'not defined $_ or $_->isa("Config::Model::Node")',
                         msg  => 'class $_ must inherit Config::Model::Node',
                     }
@@ -103,26 +106,9 @@
 
             rw_config => {
                 type              => 'node',
-                config_class_name => 'Itself::ConfigRead',
+                config_class_name => 'Itself::ConfigReadWrite',
             },
 
-            'read_config' => {
-                type  => 'list',
-                status => 'deprecated',
-                cargo => {
-                    type              => 'node',
-                    config_class_name => 'Itself::ConfigRead',
-                },
-            },
-
-            'write_config' => {
-                type  => 'list',
-                status => 'deprecated',
-                cargo => {
-                    type              => 'node',
-                    config_class_name => 'Itself::ConfigWrite',
-                },
-            },
             'accept' => {
                 type       => 'hash',
                 index_type => 'string',
@@ -147,8 +133,6 @@
             include_backend => "Include the read/write specification of another class into this class.",
             class_description => "Explain the purpose of this configuration class. This description is re-used to generate the documentation of your configuration class. You can use pod markup to format your description. See L<perlpod> for details.",
             rw_config => "Specify the backend used to read and write configuration data. See L<Config::Model::BackendMgr> for details",
-            read_config => "Obsolete - specify the Perl class(es) and function(s) used to read configuration data. The specified functions are tried in sequence to get configuration data. ",
-            write_config => "Obsolete - Specify the Perl class and function used to write configuration data.",
             generated_by => "When set, this class was generated by some program. You should not edit "
                 ."this class as your modifications may be clobbered later on when the class is regenerated.",
             accept => "Specifies names of the elements this configuration class accepts as valid. "
@@ -233,6 +217,22 @@
                }
             },
 
+            'function' => {
+                type       => 'leaf',
+                value_type => 'uniline',
+                status     => 'deprecated',
+                level      => 'hidden',
+                warp       => {
+                    follow => '- backend',
+                    rules  => [
+                        custom => {
+                            level            => 'normal',
+                            upstream_default => 'read',
+                        }
+                    ],
+                }
+            },
+
             'auto_create' => {
                 type             => 'leaf',
                 value_type       => 'boolean',
@@ -456,49 +456,6 @@
 
     ],
 
-    [
-        name    => 'Itself::ConfigRead',
-        include => "Itself::ConfigReadWrite",
-
-        'element' => [
-            'function' => {
-                type       => 'leaf',
-                value_type => 'uniline',
-                level      => 'hidden',
-                warp       => {
-                    follow => '- backend',
-                    rules  => [
-                        custom => {
-                            level            => 'normal',
-                            upstream_default => 'read',
-                        }
-                    ],
-                }
-            },
-        ],
-    ],
-
-    [
-        name    => 'Itself::ConfigWrite',
-        include => "Itself::ConfigReadWrite",
-
-        'element' => [
-            'function' => {
-                type       => 'leaf',
-                value_type => 'uniline',
-                level      => 'hidden',
-                warp       => {
-                    follow => '- backend',
-                    rules  => [
-                        custom => {
-                            level            => 'normal',
-                            upstream_default => 'write',
-                        }
-                    ],
-                }
-            },
-        ],
-    ],
     [
         name => 'Itself::ConfigAccept',
 
